import { z } from "zod";
export const jsonValueSchema = z.union([
    z.string(),
    z.number().finite(),
    z.boolean(),
    z.null(),
    z.record(z.lazy(()=>jsonValueSchema)),
    z.array(z.lazy(()=>jsonValueSchema))
]);
export function isJSONValue(value) {
    return jsonValueSchema.safeParse(value).success;
}
export function parseJSONValue(value) {
    return isJSONValue(value) ? value : undefined;
}
export const jsonArraySchema = z.array(jsonValueSchema);
export function isJSONArray(value) {
    return jsonArraySchema.safeParse(value).success;
}
export function parseJSONArray(value) {
    return isJSONArray(value) ? value : undefined;
}
export const jsonObjectSchema = z.record(jsonValueSchema);
export function isJSONObject(value) {
    return jsonObjectSchema.safeParse(value).success;
}
export function parseJSONObject(value) {
    return isJSONObject(value) ? value : undefined;
}
// Boolean
export const booleanSchema = z.boolean();
export function isBoolean(value) {
    return booleanSchema.safeParse(value).success;
}
export function parseBoolean(value) {
    return isBoolean(value) ? value : undefined;
}
// Number
export const numberSchema = z.number().finite();
export function isNumber(value) {
    return numberSchema.safeParse(value).success;
}
export function parseNumber(value) {
    return isNumber(value) ? value : undefined;
}
// String
export const stringSchema = z.string();
export function isString(value) {
    return stringSchema.safeParse(value).success;
}
export function parseString(value) {
    return isString(value) ? value : undefined;
}
// Null
export const nullSchema = z.null();
export function isNull(value) {
    return nullSchema.safeParse(value).success;
}
export function parseNull(value) {
    return isNull(value) ? value : undefined;
}
// Undefined
export function isUndefined(value) {
    return value === undefined;
}
